#include <Adafruit_CircuitPlayground.h>

// Use buttons to do a pattern reset; if now - mark <= 3000, skip to previous pattern otherwise restart current pattern

#define OFF 0, 0, 0
#define DEFAULT_DURATION 15000
#define ACTIVITIES 5

unsigned long last;
unsigned long mark;
uint16_t duration;
uint8_t active;
bool reset;

bool lastLeft;
bool lastRight;

// 30 is library default
uint8_t brightness = 30;

void setup ()
{
  CircuitPlayground.begin();
  CircuitPlayground.setBrightness(brightness);
  CircuitPlayground.clearPixels();

  last = 0;
  active = 0;
  reset = true;

  lastLeft = false;
  lastRight = false;
}

void loop ()
{
  unsigned long now = millis();
  bool done = false;
  bool slide = CircuitPlayground.slideSwitch();

  if (now - last == 0)
  {
    return;
  }

  bool button = CircuitPlayground.leftButton();
  if (button != lastLeft)
  {
    if (slide)
    {
      brightness = min(brightness + 1, 254);
      CircuitPlayground.setBrightness(brightness);
    }
    else
    {
      reset = true;
      active = (active + 1) % ACTIVITIES;
      lastLeft = button;
    }
  }

  button = CircuitPlayground.rightButton();
  if (!reset && button != lastRight)
  {
    if (slide)
    {
      brightness = max(10, brightness - 1);
      CircuitPlayground.setBrightness(brightness);
    }
    else
    {
      reset = true;
      active = active == 0 ? ACTIVITIES - 1 : active - 1;
      lastRight = button;
    }
  }

  if (reset)
  {
    mark = now;
  }

  switch (active)
  {
    case 0:
      if (reset) pacman_reset();
      done = pacman(now - mark);
      break;
    case 1:
      if (reset) fft_reset();
      done = fft(now - mark);
      break;
    case 2:
      if (reset) kitt_reset();
      done = kitt(now - mark);
      break;
    case 3:
      if (reset) thirdkind_reset();
      done = thirdkind(now - mark);
      break;
    case 4:
      if (reset) temperature_reset();
      done = temperature(now - mark);
      break;
  }

  if (reset)
  {
    reset = false;
  }

  if (done)
  {
    reset = true;

    if (!slide)
    {
      active = (active + 1) % ACTIVITIES;
    }
  }
  last = now;

  CircuitPlayground.strip.show();
}

